==> haskell-authenticate-oauth-1.7-322-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-ADdnllPF4wM4KXtxIcs3tc
key:                  authenticate-oauth-1.7-ADdnllPF4wM4KXtxIcs3tc
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  7f6a199553e3097b1c170a95bc0181c7
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-ADdnllPF4wM4KXtxIcs3tc
depends:
    RSA-2.4.1-38MSQA0uykFIEiQYWh9enN SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    base-4.17.2.1 base64-bytestring-1.2.1.0-GAmjGtWIu9x1vslmHvw2RC
    blaze-builder-0.4.4-EGbkTUZoNCK66ILpcLSXog bytestring-0.11.5.3
    crypto-pubkey-types-0.4.3-1HJmIyEamqlDcgqSCnsnrF
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    http-client-0.7.19-5xqtlAuv10Ciu8xvmO6iF
    http-types-0.12.4-CNeaCV6lRlPBtRvYIfwzr8
    random-1.2.1.3-1epqCSzcS4p5bPWcI4Ab0S time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.7-323-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-J165TstdOFZ4GQNXgJYF4G
key:                  authenticate-oauth-1.7-J165TstdOFZ4GQNXgJYF4G
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  0382f3cfe01f91b15ece3abd64d829cb
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-J165TstdOFZ4GQNXgJYF4G
depends:
    RSA-2.4.1-IRWDSDLgCa6CxXiyMYhdtC SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    base-4.17.2.1 base64-bytestring-1.2.1.0-G53UOvB3pKB2mwL6yBWItW
    blaze-builder-0.4.4-J87LvVgADYa5gww986bADm bytestring-0.11.5.3
    crypto-pubkey-types-0.4.3-4V8zzGUvSX1CdUtInDMtRu
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    http-client-0.7.19-L1utxVEiLaAGw6Jin0pjGQ
    http-types-0.12.4-J468GPAKalzFHPyn7Dxh3c
    random-1.2.1.3-9I8x2ZdyyN6LUBxcAUCXuW time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
